@@ -3,7 +3,7 @@ use warnings;
 
 package SVN::Hooks::CheckJira;
 {
-  $SVN::Hooks::CheckJira::VERSION = '1.19';
+  $SVN::Hooks::CheckJira::VERSION = '1.23';
 }
 # ABSTRACT: Integrate Subversion with the JIRA ticketing system.
 
@@ -53,9 +53,9 @@ sub CHECK_JIRA_CONFIG {
 
 sub _validate_projects {
     my ($opt, $val) = @_;
-    is_string($val) && $val =~ /^[A-Z,]+$/
-	or croak "$HOOK: $opt\'s value must be a string matching /^[A-Z,]+\$/.\n";
-    my %projects = map {$_ => undef} grep {/./} split /,/, $val;
+    is_string($val) && $val =~ /^[A-Z,\s]+$/
+	or croak "$HOOK: $opt\'s value must be a string matching /^[A-Z,\\s]+\$/.\n";
+    my %projects = map {$_ => undef} grep {/./} split /\s*,\s*/, $val;
     return \%projects;
 }
 
@@ -231,15 +231,18 @@ sub post_commit {
 1; # End of SVN::Hooks::CheckJira
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 SVN::Hooks::CheckJira - Integrate Subversion with the JIRA ticketing system.
 
 =head1 VERSION
 
-version 1.19
+version 1.23
 
 =head1 DESCRIPTION
 
@@ -460,10 +463,9 @@ Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by CPqD.
+This software is copyright (c) 2013 by CPqD.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
