@@ -3,11 +3,12 @@ use warnings;
 
 package SVN::Hooks::DenyFilenames;
 {
-  $SVN::Hooks::DenyFilenames::VERSION = '1.13';
+  $SVN::Hooks::DenyFilenames::VERSION = '1.23';
 }
 # ABSTRACT: Deny some file names.
 
 use Carp;
+use Data::Util qw(:check);
 use SVN::Hooks;
 
 use Exporter qw/import/;
@@ -17,15 +18,12 @@ our @EXPORT = ($HOOK, 'DENY_FILENAMES_PER_PATH');
 
 sub _grok_check {
     my ($directive, $check) = @_;
-    if (ref $check eq 'Regexp') {
+    if (is_rx($check)) {
 	return [$check => 'filename not allowed'];
-    } elsif (ref $check eq 'ARRAY') {
-	@$check == 2
-	    or croak "$directive: array arguments must have two arguments.\n";
-	ref $check->[0] eq 'Regexp'
-	    or croak "$directive: got \"$check->[0]\" while expecting a qr/Regex/.\n";
-	! ref $check->[1]
-	    or croak "$directive: got \"$check->[1]\" while expecting a string.\n";
+    } elsif (is_array_ref($check)) {
+	@$check == 2           or croak "$directive: array arguments must have two arguments.\n";
+	is_rx($check->[0])     or croak "$directive: got \"$check->[0]\" while expecting a qr/Regex/.\n";
+	is_string($check->[1]) or croak "$directive: got \"$check->[1]\" while expecting a string.\n";
 	return $check;
     } else {
 	croak "$directive: got \"$check\" while expecting a qr/Regex/ or a [qr/Regex/, 'message'].\n";
@@ -56,8 +54,7 @@ sub DENY_FILENAMES_PER_PATH {
 
     while (@rules) {
 	my ($match, $check) = splice @rules, 0, 2;
-	ref $match && ref $match eq 'Regexp'
-	    or croak "DENY_FILENAMES_PER_PATH: rule prefix isn't a Regexp.\n";
+	is_rx($match) or croak "DENY_FILENAMES_PER_PATH: rule prefix isn't a Regexp.\n";
 
 	push @Per_path_checks, [$match => _grok_check('DENY_FILENAMES_PER_PATH', $check)];
     }
@@ -93,15 +90,18 @@ sub pre_commit {
 1; # End of SVN::Hooks::DenyFilenames
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 SVN::Hooks::DenyFilenames - Deny some file names.
 
 =head1 VERSION
 
-version 1.13
+version 1.23
 
 =head1 SYNOPSIS
 
@@ -175,10 +175,9 @@ Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by CPqD.
+This software is copyright (c) 2013 by CPqD.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
