@@ -8,6 +8,7 @@ use File::Spec::Functions;
 use File::Path;
 use File::Copy;
 use URI::file;
+use Config;
 
 # Make sure the svn messages come in English.
 $ENV{LC_MESSAGES} = 'C';
@@ -103,15 +104,26 @@ sub set_hook {
 	or die "Can't create $hookscript: $!";
     my $debug = exists $ENV{DBG} ? '-d' : '';
     print $fd <<"EOS";
-#!$^X $debug
+#!$Config{perlpath} $debug
 use strict;
 use warnings;
 EOS
+
+    # Subversion hooks are invoked with an empty PATH. This means that
+    # if the user doesn't define it explicitly, bare commands will be
+    # invoked with execvp, which usually works as if the PATH was
+    # ":/bin:/usr/bin". During the tests we try to set up the hooks so
+    # that they will use the PATH as it is in the test environment.
+    if (defined $ENV{PATH} and length $ENV{PATH}) {
+	print $fd "BEGIN { \$ENV{PATH} = '$ENV{PATH}' }\n";
+    }
+
     if (defined $ENV{PERL5LIB} and length $ENV{PERL5LIB}) {
 	foreach my $path (reverse split "$pathsep", $ENV{PERL5LIB}) {
 	    print $fd "use lib '$path';\n";
 	}
     }
+
     print $fd <<"EOS";
 use lib '$bliblib';
 use SVN::Hooks;
@@ -134,6 +146,7 @@ EOS
 	    $hookfile .= '.cmd';
 	    open my $fd, '>', $hookfile
 		or die "Can't create $hookfile: $!";
+	    print $fd "\@echo off\n";
 	    print $fd "$^X $hookscript $hook %1 %2 %3 %4 %5\n";
 	    close $fd;
 	    chmod 0755 => $hookfile;
@@ -152,6 +165,17 @@ sub set_conf {
     close $fd;
 }
 
+sub get_author {
+    my ($t) = @_;
+    my $repo = catfile($t, 'repo');
+    open my $cmd, '-|', "svnlook info $repo"
+	or die "Can't exec svn info\n";
+    chomp(my $author = <$cmd>);
+    local $/ = undef; <$cmd>;
+    close $cmd;
+    return $author;
+}
+
 sub reset_repo {
     my $cleanup = exists $ENV{REPO_CLEANUP} ? $ENV{REPO_CLEANUP} : 1;
     $T = tempdir('t.XXXX', DIR => getcwd(), CLEANUP => $cleanup);
